:mod:`modelicares.util`
=======================

.. automodule:: modelicares.util
   :members:
   :undoc-members:
   :exclude-members: ArrowLine

.. autoclass:: modelicares.util.ArrowLine
   :exclude-members: Path
